import { Button, Popover } from "antd";
import plus from "@/assets/images/setting/plus.png";
import styles from "./index.module.css";
import { Edge, Node } from "@antv/x6";

interface GatewayNodeProps {
  edge: Edge;
  addElement: (
    type: string,
    edgeData: { target: Node.Metadata; source: Node.Metadata }
  ) => void;
}
/** 网管节点 */
const GatewayNode = (props: GatewayNodeProps) => {
  const { edge, addElement } = props;
  const edgeData = edge?.getData<{
    target: Node.Metadata;
    source: Node.Metadata;
  }>();

  return (
    <Popover
      placement="right"
      arrow={false}
      content={
        <div>
          <Button type="text" onClick={() => addElement("办理", edgeData)}>
            办理
          </Button>
          <Button type="text" onClick={() => addElement("审批", edgeData)}>
            审批
          </Button>

          {edgeData.source.id === "startEvent" && (
            <Button
              type="text"
              onClick={() => addElement("街镇条件", edgeData)}
            >
              街镇条件
            </Button>
          )}
          <Button type="text" onClick={() => addElement("可选审批", edgeData)}>
            可选审批
          </Button>
        </div>
      }
    >
      <div className={styles.actionBtn}>
        <img src={plus} alt="" style={{ width: 40, height: 40 }}></img>
      </div>
    </Popover>
  );
};

export default GatewayNode;
